@@ -20,6 +20,31 @@ from zope.publisher.interfaces import IView
 from zope.interface import Attribute, Interface, implementer, Invalid
 from zope.schema import Bool
 from zope.exceptions.interfaces import UserError
+from zope.formlib._compat import basestring
+
+class IInvalidFormError(Interface):
+
+    def doc():
+        """The form submit could not be validated.
+        """
+
+@implementer(IInvalidFormError)
+class InvalidFormError(Exception):
+    """The form submit could not be validated.
+    """
+
+class IInvalidCSRFTokenError(Interface):
+
+    def doc():
+        """The form submit could not be handled as the CSRF token is missing
+        or incorrect.
+        """
+
+@implementer(IInvalidCSRFTokenError)
+class InvalidCSRFTokenError(InvalidFormError):
+    """The form submit could not be handled as the CSRF token is missing
+    or incorrect.
+    """
 
 class IWidgetInputError(Interface):
     """Placeholder for a snippet View"""
@@ -236,7 +261,7 @@ class IDisplayWidget(IWidget):
 
 class IWidgetFactory(Interface):
     """A factory that creates the widget"""
-    
+
     def __call__(context, request):
         """Return a widget"""
 
@@ -357,7 +382,7 @@ class ISubPage(Interface):
 
 
 class IFormAPI(Interface):
-    """API to facilitate creating forms, provided by zope.formlib.form
+    """API to facilitate creating forms, provided by `zope.formlib.form`
     """
 
     def Field(schema_field, **options):
@@ -395,7 +420,7 @@ class IFormAPI(Interface):
 
 
     def Fields(*arguments, **options):
-        """Create form-fields collection (IFormFields)
+        """Create form-fields collection (`IFormFields`)
 
         Creates a form-field collection from a collection of:
 
@@ -626,13 +651,11 @@ class IFormAPI(Interface):
         that the options don't include the success option.
 
         The function is designed to be used as a decorator (Python 2.4
-        and later), as in:
-
-        @action("Edit")
-        def handle_edit(self, action, data):
-            ...
-
+        and later), as in::
 
+            @action("Edit")
+            def handle_edit(self, action, data):
+                ...
         """
 
     def validate(form, actions, form_prefix, data, default_validate=None):
@@ -754,7 +777,7 @@ class IFormBaseCustomization(ISubPage, IBrowserPage):
 
 
 class IFormFields(Interface):
-    """A colection of form fields (IFormField objects)
+    """A colection of form fields (`IFormField` objects)
     """
 
     def __len__():
@@ -786,7 +809,7 @@ class IFormFields(Interface):
         """
 
     def __add__(form_fields):
-        """Add two form fields collections (IFormFields)
+        """Add two form fields collections (`IFormFields`)
 
         Return a new IFormFields that is the concatination of the two
         IFormFields.
@@ -795,8 +818,8 @@ class IFormFields(Interface):
     def select(*names):
         """Select fields with given names in order
 
-        Return a new IFormFields that is a selection from the original
-        IFormFields that has the named fields in the specified order.
+        Return a new `IFormFields` that is a selection from the original
+        `IFormFields` that has the named fields in the specified order.
         """
 
     def omit(*names):
