@@ -17,7 +17,6 @@ __docformat__ = 'restructuredtext'
 from xml.sax.saxutils import escape
 
 from zope import component
-from zope.interface import implementer
 from zope.i18n import translate
 from zope.schema.interfaces import InvalidValue
 from zope.schema.interfaces import ITitledTokenizedTerm
@@ -152,7 +151,7 @@ class SingleDataHelper(object):
         if input:
             try:
                 return self.convertTokensToValues([input])[0]
-            except (InvalidValue, TypeError), e:
+            except (InvalidValue, TypeError) as e:
                 raise ConversionError(_("Invalid value"), e)
         else:
             return self.context.missing_value
@@ -192,7 +191,7 @@ class MultiDataHelper(object):
             input = [input]
         try:
             values = self.convertTokensToValues(input)
-        except InvalidValue, e:
+        except InvalidValue as e:
             raise ConversionError(_("Invalid value"), e)
 
         # All AbstractCollection fields have a `_type` attribute specifying
@@ -299,7 +298,7 @@ class SetDisplayWidget(ItemsMultiDisplayWidget):
 EXPLICIT_EMPTY_SELECTION = True
 
 
-@implementer(IInputWidget)
+
 class ItemsEditWidgetBase(SingleDataHelper, ItemsWidgetBase):
     """Widget Base for rendering item-related fields.
 
@@ -628,4 +627,3 @@ class MultiCheckBoxWidget(ItemsMultiEditWidgetBase):
         return renderElement(u'label',
                              contents=contents,
                              **{'for': id})
-
