@@ -21,7 +21,7 @@ from zope.schema import TextLine
 from doctest import DocTestSuite
 
 from zope.formlib.widget import DisplayWidget, UnicodeDisplayWidget
-
+from .support import checker
 
 def test_implemented_interfaces():
     """Make sure that the display widget implements the correct interfaces.
@@ -30,18 +30,20 @@ def test_implemented_interfaces():
     `IBrowserWidget`.
 
     >>> from zope.formlib.interfaces import IBrowserWidget
+    >>> from zope.interface import implementedBy
+    >>> from zope.interface.verify import verifyClass
+    >>> IBrowserWidget in implementedBy(DisplayWidget)
+    True
     >>> verifyClass(IBrowserWidget, DisplayWidget)
     True
 
     But unlike most other widgets in this package, the display widget is *not*
     an `IInputWidget`.
 
+
     >>> from zope.formlib.interfaces import IInputWidget
-    >>> try:
-    ...     verifyClass(IInputWidget, DisplayWidget)    
-    ... except DoesNotImplement:
-    ...     'not implemented'
-    'not implemented'
+    >>> IInputWidget in implementedBy(DisplayWidget)
+    False
     """
 
 def test_not_required():
@@ -53,7 +55,7 @@ def test_not_required():
     >>> widget = DisplayWidget(field, TestRequest())
     >>> widget.required
     False
-    
+
     """
 
 def test_value_escaping():
@@ -118,9 +120,10 @@ def test_value_escaping():
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTest(DocTestSuite())
+    suite.addTest(DocTestSuite(checker=checker))
     suite.addTest(DocTestSuite(
-        extraglobs={"DisplayWidget": UnicodeDisplayWidget}))
+            checker=checker,
+            extraglobs={"DisplayWidget": UnicodeDisplayWidget}))
     return suite
 
 if __name__ == '__main__':
