@@ -64,10 +64,10 @@ class SequenceWidgetTestHelper(object):
 
     def tearDown(self):
         traversingTearDown()
-        
+
     def _FieldFactory(self, **kw):
         kw.update({
-            '__name__': u'foo', 
+            '__name__': u'foo',
             'value_type': TextLine(__name__=u'bar')})
         return Tuple(**kw)
 
@@ -97,11 +97,11 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
                        IWidgetInputErrorView, '')
 
     def test_haveNoData(self):
-        self.failIf(self._widget.hasInput())
+        self.assertFalse(self._widget.hasInput())
 
     def test_hasInput(self):
         self._widget.request.form['field.foo.count'] = u'0'
-        self.failUnless(self._widget.hasInput())
+        self.assertTrue(self._widget.hasInput())
 
     def test_customWidgetFactory(self):
         """Verify that the widget can be constructed via the CustomWidgetFactory
@@ -147,28 +147,28 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
         request = TestRequest()
         widget = ListSequenceWidget(
             self.field, self.field.value_type, request)
-        self.failIf(widget.hasInput())
+        self.assertFalse(widget.hasInput())
         self.assertRaises(MissingInputError, widget.getInputValue)
 
         request = TestRequest(form={'field.foo.add': u'Add bar',
                                     'field.foo.count': u'0'})
         widget = ListSequenceWidget(
             self.field, self.field.value_type, request)
-        self.assert_(widget.hasInput())
+        self.assertTrue(widget.hasInput())
         self.assertRaises(WidgetInputError, widget.getInputValue)
 
         request = TestRequest(form={'field.foo.0.bar': u'Hello world!',
                                     'field.foo.count': u'1'})
         widget = ListSequenceWidget(
             self.field, self.field.value_type, request)
-        self.assert_(widget.hasInput())
-        self.assertEquals(widget.getInputValue(), [u'Hello world!'])
+        self.assertTrue(widget.hasInput())
+        self.assertEqual(widget.getInputValue(), [u'Hello world!'])
 
     def test_new(self):
         request = TestRequest()
         widget = TupleSequenceWidget(
             self.field, self.field.value_type, request)
-        self.failIf(widget.hasInput())
+        self.assertFalse(widget.hasInput())
         self.assertRaises(MissingInputError, widget.getInputValue)
         check_list = ('input', 'name="field.foo.add"')
         self.verifyResult(widget(), check_list)
@@ -178,7 +178,7 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
                                     'field.foo.count': u'0'})
         widget = TupleSequenceWidget(
             self.field, self.field.value_type, request)
-        self.assert_(widget.hasInput())
+        self.assertTrue(widget.hasInput())
         self.assertRaises(WidgetInputError, widget.getInputValue)
         check_list = (
             'checkbox', 'field.foo.remove_0', 'input', 'field.foo.0.bar',
@@ -191,15 +191,15 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
                                     'field.foo.count': u'1'})
         widget = TupleSequenceWidget(
             self.field, self.field.value_type, request)
-        self.assert_(widget.hasInput())
-        self.assertEquals(widget.getInputValue(), (u'Hello world!',))
+        self.assertTrue(widget.hasInput())
+        self.assertEqual(widget.getInputValue(), (u'Hello world!',))
 
     def test_existing(self):
         request = TestRequest()
         widget = TupleSequenceWidget(
             self.field, self.field.value_type, request)
         widget.setRenderedValue((u'existing',))
-        self.failIf(widget.hasInput())
+        self.assertFalse(widget.hasInput())
         self.assertRaises(MissingInputError, widget.getInputValue)
         check_list = (
             'checkbox', 'field.foo.remove_0', 'input', 'field.foo.0.bar',
@@ -209,7 +209,7 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
         )
         self.verifyResult(widget(), check_list, inorder=True)
         widget.setRenderedValue((u'existing', u'second'))
-        self.failIf(widget.hasInput())
+        self.assertFalse(widget.hasInput())
         self.assertRaises(MissingInputError, widget.getInputValue)
         check_list = (
             'checkbox', 'field.foo.remove_0', 'input', 'field.foo.0.bar',
@@ -230,7 +230,7 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
         widget = TupleSequenceWidget(
             self.field, self.field.value_type, request)
         widget.setRenderedValue((u'existing', u'second'))
-        self.assertEquals(widget.getInputValue(), (u'second',))
+        self.assertEqual(widget.getInputValue(), (u'second',))
         check_list = (
             'checkbox', 'field.foo.remove_0', 'input', 'field.foo.0.bar',
                 'existing',
@@ -255,7 +255,7 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
         )
         s = widget()
         self.verifyResult(s, check_list, inorder=True)
-        self.assertEquals(s.find('checkbox'), -1)
+        self.assertEqual(s.find('checkbox'), -1)
 
     def test_max(self):
         request = TestRequest()
@@ -265,7 +265,7 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
         widget.setRenderedValue((u'existing',))
         self.assertRaises(MissingInputError, widget.getInputValue)
         s = widget()
-        self.assertEquals(s.find('field.foo.add'), -1)
+        self.assertEqual(s.find('field.foo.add'), -1)
 
     def test_anonymousfield(self):
         self.field = Tuple(__name__=u'foo', value_type=TextLine())
@@ -293,7 +293,7 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
         widget()
 
         data = widget._generateSequence()
-        self.assertEquals(data, [None, u'nonempty'])
+        self.assertEqual(data, [None, u'nonempty'])
 
     def doctest_widgeterrors(self):
         """Test that errors on subwidgets appear
@@ -308,7 +308,7 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
 
          If we render the widget, we see no errors:
 
-            >>> print widget()
+            >>> print(widget())
             <BLANKLINE>
             ...
             <tr>
@@ -330,7 +330,7 @@ class SequenceWidgetTest(SequenceWidgetTestHelper, BrowserWidgetTest):
             >>> widget.hasValidInput()
             False
 
-            >>> print widget()
+            >>> print(widget())
             <BLANKLINE>
             ...
             <tr>
@@ -364,14 +364,14 @@ class SequenceDisplayWidgetTest(
             self.field, self.field.value_type, self.request)
         provideAdapter(DisplayWidget, (ITextLine, IDefaultBrowserLayer),
                        IDisplayWidget)
-        
+
     def test_render_empty(self):
         self.content.foo = ()
-        self.assertEquals(self.widget(), '(no values)')
+        self.assertEqual(self.widget(), '(no values)')
 
     def test_render_missing(self):
         self.content.foo = self.field.missing_value
-        self.assertEquals(self.widget(), '(no value available)')
+        self.assertEqual(self.widget(), '(no value available)')
 
     def test_render_single(self):
         self.content.foo = (u'one value',)
