@@ -14,14 +14,14 @@
 """Source Widget Tests
 """
 from zope.component import testing
+from .support import checker
 
 def test_suite():
     import doctest
     return doctest.DocFileSuite(
-        '../source.txt',
-        setUp=testing.setUp, tearDown=testing.tearDown)
+        '../source.rst',
+        setUp=testing.setUp, tearDown=testing.tearDown, checker=checker)
 
 if __name__ == '__main__':
     import unittest
     unittest.main(defaultTest='test_suite')
-
