@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 ##############################################################################
 #
 # Copyright (c) 2001, 2002, 2004, 2005 Zope Foundation and Contributors.
@@ -41,6 +42,7 @@ from zope.formlib.widgets import URIDisplayWidget
 
 from zope.formlib.tests.test_browserwidget import BrowserWidgetTest
 from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
+from zope.formlib.tests.support import checker
 
 class TextWidgetTest(SimpleInputWidgetTest):
     """Documents and tests the text widget.
@@ -131,13 +133,21 @@ class TextWidgetTest(SimpleInputWidgetTest):
         self._widget.extra = 'style="color: red"'
         self.verifyResult(self._widget.hidden(), check_list)
 
+    def testRenderUTF8Input(self):
+        value = u"☃".encode('utf-8')  # results in \u2603
+        self._widget.setRenderedValue(value)
+        check_list = ('type="text"', 'id="field.foo"', 'name="field.foo"',
+                      u'value="\u2603"', 'size="20"')
+        self.verifyResult(self._widget(), check_list)
+
+
 class URIDisplayWidgetTest(BrowserWidgetTest):
 
     _WidgetFactory = URIDisplayWidget
 
     def testProperties(self):
         # check the default linkTarget
-        self.failIf(self._widget.linkTarget)
+        self.assertFalse(self._widget.linkTarget)
 
     def testRender(self):
         value = "uri:fake"
@@ -149,9 +159,9 @@ class URIDisplayWidgetTest(BrowserWidgetTest):
 
     def testEmptyRenderReturnsEmptyString(self):
         self._widget.setRenderedValue(None)
-        self.assertEquals(self._widget(), "")
+        self.assertEqual(self._widget(), "")
         self._widget.setRenderedValue('')
-        self.assertEquals(self._widget(), "")
+        self.assertEqual(self._widget(), "")
 
 
 class DateDisplayWidgetTest(BrowserWidgetTest):
@@ -162,10 +172,10 @@ class DateDisplayWidgetTest(BrowserWidgetTest):
 
     def setUp(self):
         super(DateDisplayWidgetTest, self).setUp()
-        self._value = datetime.date(2004, 12, 01)
+        self._value = datetime.date(2004, 12, 0o1)
 
     def testDefaultDisplayStyle(self):
-        self.failIf(self._widget.displayStyle)
+        self.assertFalse(self._widget.displayStyle)
 
     def testRenderDefault(self):
         self._widget.setRenderedValue(self._value)
@@ -222,7 +232,7 @@ class DatetimeDisplayWidgetTest(DateDisplayWidgetTest):
 
     def setUp(self):
         super(DatetimeDisplayWidgetTest, self).setUp()
-        self._value = datetime.datetime(2004, 12, 01, 14, 39, 01)
+        self._value = datetime.datetime(2004, 12, 0o1, 14, 39, 0o1)
 
     def testRenderDefault(self):
         super(DatetimeDisplayWidgetTest, self).testRenderDefault()
@@ -256,7 +266,7 @@ class TextAreaDisplayWidgetTest(BrowserWidgetTest):
         texttexttexttexttexttexttexttexttexttexttexttexttexttexttext
         """
         self._widget.setRenderedValue(value)
-        self.assert_(value, self._widget._toFieldValue(value))
+        self.assertTrue(value, self._widget._toFieldValue(value))
         self.verifyResult(self._widget(), ["<textarea",
                                            self._widget._toFormValue(value)])
         check_list = (
@@ -281,7 +291,7 @@ class BytesAreaDisplayWidgetTest(BrowserWidgetTest):
         texttexttexttexttexttexttexttexttexttexttexttexttexttexttext
         """
         self._widget.setRenderedValue(value)
-        self.assert_(value, self._widget._toFieldValue(value))
+        self.assertTrue(value, self._widget._toFieldValue(value))
         self.verifyResult(self._widget(), ["<textarea",
                                            self._widget._toFormValue(value)])
         check_list = (
@@ -334,11 +344,11 @@ class PasswordDisplayWidgetTest(BrowserWidgetTest):
     def testUnchangedPassword(self):
         # The password hasn't been set yet, so an empty string
         # is regarded as an empty field.
-        self.assertEquals(None, self._widget._toFieldValue(''))
+        self.assertEqual(None, self._widget._toFieldValue(''))
         # Now the password has been filled in, so the empty string
         # is regarded as the special value for UNCHANGED_PASSWORD.
         self._widget.context.context.foo = u'existing password'
-        self.assertEquals(self._widget.context.UNCHANGED_PASSWORD, 
+        self.assertEqual(self._widget.context.UNCHANGED_PASSWORD, 
                           self._widget._toFieldValue(''))
 
 class FileDisplayWidgetTest(BrowserWidgetTest):
@@ -396,7 +406,7 @@ def test_w_nonrequired_and_missing_value_and_no_inout():
     >>> def normalize(s):
     ...   return '\\n  '.join(filter(None, s.split(' ')))
 
-    >>> print normalize( widget() )
+    >>> print(normalize( widget() ))
     <input
       class="textType"
       id="field.foo"
@@ -419,7 +429,7 @@ def test_no_error_on_render_only():
     >>> request = TestRequest(form={'field.foo': ''})
     >>> widget = TextWidget(field, request)
     >>> ignored = widget()
-    >>> unicode(widget.error())
+    >>> str(widget.error())
     u''
 
 
@@ -435,7 +445,7 @@ def test_text_area_works_with_missing_value():
     >>> def normalize(s):
     ...   return '\\n  '.join(filter(None, s.split(' ')))
 
-    >>> print normalize( widget() )
+    >>> print(normalize( widget() ))
     <textarea
       cols="60"
       id="field.foo"
@@ -443,7 +453,7 @@ def test_text_area_works_with_missing_value():
       rows="15"
       ></textarea>
 
-    >>> print normalize( widget.hidden() )
+    >>> print(normalize( widget.hidden() ))
     <input
       class="hiddenType"
       id="field.foo"
@@ -467,7 +477,7 @@ def test_suite():
         unittest.makeSuite(FloatDisplayWidgetTest),
         unittest.makeSuite(BytesDisplayWidgetTest),
         unittest.makeSuite(ASCIIDisplayWidgetTest),
-        doctest.DocTestSuite(),
+        doctest.DocTestSuite(checker=checker),
         ))
 
 if __name__=='__main__':
